about summary refs log tree commit diff
path: root/app/lib/command_tag/processor.rb
diff options
context:
space:
mode:
Diffstat (limited to 'app/lib/command_tag/processor.rb')
-rw-r--r--app/lib/command_tag/processor.rb4
1 files changed, 3 insertions, 1 deletions
diff --git a/app/lib/command_tag/processor.rb b/app/lib/command_tag/processor.rb
index f758994a0..8461e902f 100644
--- a/app/lib/command_tag/processor.rb
+++ b/app/lib/command_tag/processor.rb
@@ -300,11 +300,13 @@ class CommandTag::Processor
             @account.user.setting_default_privacy
           when 'to', 'allow', 'allow-from', 'from'
             'cc'
+          when 'm', 'l', 'mp', 'monsterpit', 'local'
+            'community'
           else
             arg.strip
           end
 
     %w(public unlisted private limited direct cc).include?(arg) ? arg : nil
   end
 
   def read_falsy_from(arg)
@@ -300,11 +300,13 @@ class CommandTag::Processor
           end
 
-    %w(public unlisted private limited direct cc).include?(arg) ? arg : nil
+    %w(public unlisted private limited direct cc community).include?(arg) ? arg : nil
   end
 